/*
 * Desc: Accessible and semantically valid card component(s).
 *
 */
(function (Drupal, once) {
  Drupal.behaviors.inclusive_card = {
    attach: function (context) {
      let cards = once(
        "inclusive-card",
        context.querySelectorAll(".inclusive-card")
      );
      cards.forEach(cardInclusive);
    },
  };

  /**
   *
   * @param {HTMLElement} card
   * @returns {void}
   *
   * @description
   *  - Adds click event to card if it has a link
  */
  function cardInclusive(card) {
    let cardHeader = card.dataset.inclusiveCardHeader;
    let cardImg = card.dataset.inclusiveCardImg;
    if (cardHeader === "undefined") {
      return;
    }
    let down,
      up,
      link = card.querySelector(cardHeader + " a");
    if (link === undefined) {
      return;
    }
    if (cardImg !== "undefined") {
      let img = card.querySelector('img');
      if (img === undefined) {
        return;
      }

      img.removeAttribute("alt");
      img.setAttribute("role", "presentation");
        if (img && img.parentNode.tagName.toLowerCase() === 'a') {
    var parent = img.parentNode;
    while (parent.firstChild) {
      parent.parentNode.insertBefore(parent.firstChild, parent);
    }
    parent.parentNode.removeChild(parent);
  }

    }
    card.onmousedown = () => (down = +new Date());
    card.onmouseup = () => {
      up = +new Date();
      if (up - down < 200) {
        link.click();
      }
    };
    card.style.cursor = "pointer";
  }
})(Drupal, once);
